==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/mixer/template/quota/QuotaListFluent.java <==
package me.snowdrop.istio.mixer.template.quota;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import javax.validation.constraints.NotNull;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.Deprecated;
import javax.validation.Valid;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface QuotaListFluent<A extends QuotaListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A addToItems(int index,me.snowdrop.istio.mixer.template.quota.Quota item);
    public A setToItems(int index,me.snowdrop.istio.mixer.template.quota.Quota item);
    public A addToItems(me.snowdrop.istio.mixer.template.quota.Quota... items);
    public A addAllToItems(Collection<me.snowdrop.istio.mixer.template.quota.Quota> items);
    public A removeFromItems(me.snowdrop.istio.mixer.template.quota.Quota... items);
    public A removeAllFromItems(Collection<me.snowdrop.istio.mixer.template.quota.Quota> items);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<me.snowdrop.istio.mixer.template.quota.Quota> getItems();
    public List<me.snowdrop.istio.mixer.template.quota.Quota> buildItems();
    public me.snowdrop.istio.mixer.template.quota.Quota buildItem(int index);
    public me.snowdrop.istio.mixer.template.quota.Quota buildFirstItem();
    public me.snowdrop.istio.mixer.template.quota.Quota buildLastItem();
    public me.snowdrop.istio.mixer.template.quota.Quota buildMatchingItem(Predicate<me.snowdrop.istio.mixer.template.quota.QuotaBuilder> predicate);
    public A withItems(List<me.snowdrop.istio.mixer.template.quota.Quota> items);
    public A withItems(me.snowdrop.istio.mixer.template.quota.Quota... items);
    public Boolean hasItems();
    public QuotaListFluent.ItemsNested<A> addNewItem();
    public QuotaListFluent.ItemsNested<A> addNewItemLike(me.snowdrop.istio.mixer.template.quota.Quota item);
    public QuotaListFluent.ItemsNested<A> setNewItemLike(int index,me.snowdrop.istio.mixer.template.quota.Quota item);
    public QuotaListFluent.ItemsNested<A> editItem(int index);
    public QuotaListFluent.ItemsNested<A> editFirstItem();
    public QuotaListFluent.ItemsNested<A> editLastItem();
    public QuotaListFluent.ItemsNested<A> editMatchingItem(Predicate<me.snowdrop.istio.mixer.template.quota.QuotaBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends Nested<N>,me.snowdrop.istio.mixer.template.quota.QuotaFluent<QuotaListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/mixer/template/quota/QuotaListFluent.java <==
package me.snowdrop.istio.mixer.template.quota;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface QuotaListFluent<A extends QuotaListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,me.snowdrop.istio.mixer.template.quota.Quota item);
    public A setToItems(int index,me.snowdrop.istio.mixer.template.quota.Quota item);
    public A addToItems(me.snowdrop.istio.mixer.template.quota.Quota... items);
    public A addAllToItems(Collection<me.snowdrop.istio.mixer.template.quota.Quota> items);
    public A removeFromItems(me.snowdrop.istio.mixer.template.quota.Quota... items);
    public A removeAllFromItems(Collection<me.snowdrop.istio.mixer.template.quota.Quota> items);
    public A removeMatchingFromItems(Predicate<me.snowdrop.istio.mixer.template.quota.QuotaBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<me.snowdrop.istio.mixer.template.quota.Quota> getItems();
    public List<me.snowdrop.istio.mixer.template.quota.Quota> buildItems();
    public me.snowdrop.istio.mixer.template.quota.Quota buildItem(int index);
    public me.snowdrop.istio.mixer.template.quota.Quota buildFirstItem();
    public me.snowdrop.istio.mixer.template.quota.Quota buildLastItem();
    public me.snowdrop.istio.mixer.template.quota.Quota buildMatchingItem(Predicate<me.snowdrop.istio.mixer.template.quota.QuotaBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<me.snowdrop.istio.mixer.template.quota.QuotaBuilder> predicate);
    public A withItems(List<me.snowdrop.istio.mixer.template.quota.Quota> items);
    public A withItems(me.snowdrop.istio.mixer.template.quota.Quota... items);
    public Boolean hasItems();
    public QuotaListFluent.ItemsNested<A> addNewItem();
    public QuotaListFluent.ItemsNested<A> addNewItemLike(me.snowdrop.istio.mixer.template.quota.Quota item);
    public QuotaListFluent.ItemsNested<A> setNewItemLike(int index,me.snowdrop.istio.mixer.template.quota.Quota item);
    public QuotaListFluent.ItemsNested<A> editItem(int index);
    public QuotaListFluent.ItemsNested<A> editFirstItem();
    public QuotaListFluent.ItemsNested<A> editLastItem();
    public QuotaListFluent.ItemsNested<A> editMatchingItem(Predicate<me.snowdrop.istio.mixer.template.quota.QuotaBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends Nested<N>,me.snowdrop.istio.mixer.template.quota.QuotaFluent<QuotaListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}


}
